@@ -1,39 +1,33 @@
 g3a_predate_catchability_totalfleet <- function (E) {
-    list(
-        suit_unit = "total biomass",
-        suit = quote( suit_f * stock_ss(stock__num) * stock_ss(stock__wgt) ),
-        cons = f_substitute(
-            ~stock_ss(predprey__suit) * (E / total_predsuit),
-            list(E = E)) )
+    g3a_predate_catchability_project(
+        landings_f = E,
+        unit = "biomass" )
 }
 
 g3a_predate_catchability_numberfleet <- function (E) {
-    list(
-        suit_unit = "number of individuals",
-        suit = quote( suit_f * stock_ss(stock__num) ),
-        cons = f_substitute(
-            ~stock_ss(predprey__suit) * (E / total_predsuit) * stock_ss(stock__wgt),
-            list(E = E)) )
+    g3a_predate_catchability_project(
+        landings_f = E,
+        unit = "individuals" )
 }
 
 g3a_predate_catchability_linearfleet <- function (E) {
-    list(
-        suit_unit = "total biomass",
-        suit = quote( suit_f * stock_ss(stock__num) * stock_ss(stock__wgt) ),
-        cons = f_substitute(
-            # NB: Divide by cur_step_size, assuming E is per-year
-            ~E * cur_step_size * stock_ss(predprey__suit),
-            list(E = E)) )
+    g3a_predate_catchability_project(
+        landings_f = E,
+        cons_step = quote( cur_step_size ),
+        unit = "harvest-rate-year" )
 }
 
 g3a_predate_catchability_project <- function (
     quota_f = NULL,
     landings_f = NULL,
+    interim_f = g3_parameterized("quota.interim", value = 0,
+        by_predator = TRUE, by_step = TRUE),
     # Proportion of quota assigned to predator
     quota_prop = g3_parameterized("quota.prop", by_predator = TRUE, value = 1),
     # Proportion of predator yearly quota assigned to which step
     cons_step = g3_parameterized("cons.step", by_predator = TRUE, by_step = TRUE,
         value = quote( step_lengths / 12.0 )),
+    interim_unit = unit,
     unit = c("biomass", "biomass-year", "harvest-rate", "harvest-rate-year",
              "individuals", "individuals-year") ) {
 
@@ -41,6 +35,8 @@ g3a_predate_catchability_project <- function (
     landings_unit <- match.arg(unit)
     # Unit quota_f is expressed in
     quota_unit <- match.arg(attr(quota_f, "catchability_unit"), eval(formals()$unit))
+    # Unit interim_f is expresed in
+    interim_unit <- match.arg(unit)
     # Unit suitability / total_predsuit will be expressed in
     suit_unit <- if (startsWith(landings_unit, "individuals")) "individuals" else "biomass"
 
@@ -53,34 +49,55 @@ g3a_predate_catchability_project <- function (
     adapt <- function (f, unit) {
         if (is.null(f)) return(f)
 
-        # if f returns biomass / individuals
         if (startsWith(unit, "biomass")) {
+            # Scale f by proportion of all suitable stock in this lengthgroup
             if (suit_unit == "individuals") stop("Cannot use a quota in biomass with landings in individuals")
-            f <- f_substitute(quote( f / total_predsuit ), list(f = f))
-        }
-        if (startsWith(unit, "individuals")) {
+            f <- f_substitute(quote( f * (stock_ss(predprey__suit) / total_predsuit) ), list(f = f))
+        } else if (startsWith(unit, "individuals")) {
+            # Scale f by proportion of all suitable stock in this lengthgroup
             if (suit_unit == "biomass") stop("Cannot use a quota in individuals with landings in biomass")
-            f <- f_substitute(quote( f / total_predsuit ), list(f = f))
+            f <- f_substitute(quote( f * (stock_ss(predprey__suit) / total_predsuit) ), list(f = f))
+        } else if (startsWith(unit, "harvest-rate")) {
+            # Scale suitable stock in this lengthgroup by f
+            f <- f_substitute(quote( stock_ss(predprey__suit) * f ), list(f = f))
+        } else {
+            stop("Unknown unit string ", unit)
         }
         if (endsWith(unit, "-year")) {
             f <- f_substitute(quote( f * cons_step ), list(f = f, cons_step = cons_step))
         }
+
+        if (suit_unit == "individuals") {
+            # Suitability is in individuals, so f will be at this point. Convert back to biomass
+            f <- f_substitute(quote( f * stock_ss(stock__wgt) ), list(f = f))
+        }
         return(f)
     }
+    pre_scale_quota_f <- quota_f
     quota_f <- adapt(quota_f, quota_unit)
     landings_f <- adapt(landings_f, landings_unit)
+    interim_f <-  adapt(interim_f, interim_unit)
 
     # Combine quota/landings into a single formula
     if (is.null(quota_f)) {
         combined_f <- landings_f
-    } else if (is.null(landings_f)) {
-        combined_f <- quota_f
     } else {
-        combined_f <- f_substitute(
-            quote( if (cur_year_projection) quota_f else landings_f ),
-            list(
+        combined_f <- quota_f
+        if (!is.null(interim_f)) {
+            combined_f <- f_substitute(quote(
+                if (is.nan(pre_scale_quota_f)) interim_f else combined_f
+            ), list(
+                pre_scale_quota_f = pre_scale_quota_f,
+                interim_f = interim_f,
+                combined_f = combined_f ))
+        }
+        if (!is.null(landings_f)) {
+            combined_f <- f_substitute(quote(
+                if (cur_year_projection) combined_f else landings_f
+            ), list(
                 landings_f = landings_f,
-                quota_f = quota_f ))
+                combined_f = combined_f ))
+        }
     }
 
     # Return catchablity based on suit_unit
@@ -88,16 +105,12 @@ g3a_predate_catchability_project <- function (
         list(
             suit_unit = "total biomass",
             suit = quote( suit_f * stock_ss(stock__num) * stock_ss(stock__wgt) ),
-            cons = f_substitute(
-                quote( stock_ss(predprey__suit) * combined_f ),
-                list(combined_f = combined_f)) )
+            cons = combined_f )
     } else if (suit_unit == "individuals") {
         list(
             suit_unit = "number of individuals",
             suit = quote( suit_f * stock_ss(stock__num) ),
-            cons = f_substitute(
-                quote( stock_ss(predprey__suit) * combined_f * stock_ss(stock__wgt) ),
-                list(combined_f = combined_f)) )
+            cons = combined_f )
     } else stop("Unknown suitability unit ", suit_unit)
 }
 
