@@ -48,6 +48,10 @@ cpp_code <- function(in_call, in_envir, indent = "\n    ", statement = FALSE, ex
                 # When considering a global formula, consider the init condition
                 env_defn <- attr(env_defn, "g3_global_init_val")
             }
+            if (is.call(env_defn)) {
+                # If defined with code, recurse into definition
+                return(value_is_scalar(if (rlang::is_formula(env_defn)) rlang::f_rhs(env_defn) else env_defn, fallback = fallback))
+            }
             return(is.numeric(env_defn) && !is.array(env_defn) && !is_force_vector(env_defn))
         }
 
@@ -64,12 +68,12 @@ cpp_code <- function(in_call, in_envir, indent = "\n    ", statement = FALSE, ex
         }
 
         # Common functions returning scalar from any arrays
-        if (is.call(c_val) && as.character(c_val[[1]]) %in% c("sum", "prod", "mean", "g3_idx")) {
+        if (is.call(c_val) && as.character(c_val[[1]]) %in% c("sum", "prod", "mean", "g3_idx", "g3_param", "logspace_add")) {
             return(TRUE)
         }
 
         # Operators that will return a same-length array
-        if (is.call(c_val) && as.character(c_val[[1]]) %in% c("-", "+", "*", "/", "%/%", "%%")) return(all(vapply(
+        if (is.call(c_val) && as.character(c_val[[1]]) %in% c("(", "-", "+", "*", "/", "%/%", "%%")) return(all(vapply(
             tail(c_val, -1),
             value_is_scalar,
             logical(1) )))
@@ -232,6 +236,18 @@ cpp_code <- function(in_call, in_envir, indent = "\n    ", statement = FALSE, ex
             assign_rhs <- assign_rhs[[3]]
         }
 
+        # Turn top-level tertiary operators inside-out, to duck eigen type mismatches
+        if (is.call(assign_rhs)
+                && statement
+                && length(assign_rhs) == 4  # NB: Do this first so x <- y() doesn't trip us up
+                && identical(assign_rhs[[1]], as.symbol("if"))) {
+            return(cpp_code(call(
+                "if", assign_rhs[[2]],
+                # NB: f_optimize() will get rid of any braces, which out of context are surplus to requriements
+                call("<-", assign_lhs, f_optimize(assign_rhs[[3]])),
+                call("<-", assign_lhs, f_optimize(assign_rhs[[4]])) ), in_envir, next_indent, statement = TRUE))
+        }
+
         return(paste(
             cpp_code(assign_lhs, in_envir, next_indent),  # NB: Should either be a sybol or a subset
             assign_op,
@@ -1410,11 +1426,19 @@ g3_tmb_relist <- function (parameters, par) {
         stop("Names of values in par don't match names of parameters$value")
     }
 
+    # Subset type to only include vars in par (we shouldn't transform fixed params, as we're not replacing them)
+    out_type <- unclass(parameters$type[
+        (if (include_random) parameters$random else FALSE) |
+        parameters$optimise])
+
     # Relist based on table's value
     # NB: Subset should match eqivalent operation in g3_tmb_par()
     out <- utils::relist(par, unclass(parameters$value[
         (if (include_random) parameters$random else FALSE) |
         parameters$optimise]))
+    # Convert any logarithmic params back to linear space
+    logarithmic <- grepl("(^|:)LOG(:|$)", out_type)
+    out[logarithmic] <- lapply(out[logarithmic], exp)
     # Copy unoptimised parameters from table
     out <- c(parameters$value[!(
         (if (include_random) parameters$random else FALSE) |
@@ -1422,9 +1446,5 @@ g3_tmb_relist <- function (parameters, par) {
     # Re-order to match template list
     out <- out[names(parameters$value)]
 
-    # Convert any logarithmic params back to linear space
-    logarithmic <- grepl("(^|:)LOG(:|$)", parameters$type)
-    out[logarithmic] <- lapply(out[logarithmic], exp)
-
     return(out)
 }
