@@ -15,7 +15,7 @@ actions <- list(
                 init = g3_formula( 2L + 2L ),
                 "2002" = g3_formula( y * 4L, y = 10L ),
                 "2003-02" = g3_formula( z * 2L, z = 9L ),
-                "2999" = NaN)))),
+                "2999" = -99L)))),
         "999:ut" = g3_formula( nll <- nll + g3_param('tmb_bodge', value = 1.0) )))
 actions <- c(actions, list(g3a_report_history(actions, var_re = "^tvout$")))
 
